@@ -25,8 +25,8 @@
 #define QT_FEATURE_build_all -1
 #define QT_FEATURE_c__11 1
 #define QT_FEATURE_c__14 1
-#define QT_FEATURE_c__17 -1
-#define QT_FEATURE_c__1z -1
+#define QT_FEATURE_c__17 1
+#define QT_FEATURE_c__1z 1
 #define QT_FEATURE_c__2a -1
 #define QT_FEATURE_c99 1
 #define QT_FEATURE_c11 1
@@ -38,6 +38,7 @@
 #define QT_FEATURE_force_asserts -1
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_COMPILER_SUPPORTS_RDRND 1
+#define QT_COMPILER_SUPPORTS_RDSEED 1
 #define QT_VISIBILITY_AVAILABLE true
 #define QT_REDUCE_RELOCATIONS true
 #define QT_FEATURE_separate_debug_info -1
@@ -45,7 +46,7 @@
 #define QT_FEATURE_signaling_nan 1
 #define QT_FEATURE_static -1
 #define QT_COMPILER_SUPPORTS_SIMD_ALWAYS 1
-#define QT_VERSION_STR "5.15.4"
+#define QT_VERSION_STR "5.15.6"
 #define QT_VERSION_MAJOR 5
 #define QT_VERSION_MINOR 15
-#define QT_VERSION_PATCH 4
+#define QT_VERSION_PATCH 6
